Shell

Struct Shell 

pub struct Shell<'a> { /* private fields */ }
Interactive WhyOS shell loop.

Implementations

Source

impl<'a> Shell<'a>

pub fn new( input: &'a Queue<u8, BUFFER_SIZE>, output_fn: OutputFn, user_programs: &'a [Program], ) -> Self

Creates a new Shell.

Output function is then used as a callback by uprint! and uprintln! macros. Provided user programs will be listed and executable along with builtin, example programs.

pub fn run(&mut self) -> !

Runs the shell forever until the system stops the task.

Blocks waiting for data to be available in input queue.

Supports:

  • ENTER - attempts to parse and execute command stored inside the buffer.
  • CTRL+C - attempts to kill the last executed program.
  • BACKSPACE - removes the last character in buffer if available.
  • _ - pushes the character into the buffer, if not full, check BUFFER_SIZE.